<?php

namespace App\View\Helper;

use Cake\Core\Configure;
use Cake\View\Helper;
use Cake\View\StringTemplateTrait;
use Cake\I18n\I18n;

use App\View\Helper\ScoreHelper;

class ListsHelper extends Helper
{

    use StringTemplateTrait;

    protected $_defaultConfig = [
        'templates' => [
            'review' => '
                        <li {{reviewLi}}>
                            <div {{attrsReview}}>
                                <div class="row">
                                    <div {{AttrsBootstrap1}}>
                                    <p {{AttrsUserName}}>{{userName}}</p>
                                    <p>{{stars}}</p>
                                    <p>{{created}}</p>
                                </div>
                                <div {{AttrsBootstrap2}}>
                                    <h3>{{title}}</h3>
                                    <p>{{reviewComment}}</p>
                                </div>
                                </div>
                                 
                            </div>
                        </li>'
            ,
            'stars' => '<span {{attrGlyph}}><span {{attrStar}}>{{content}}</span></span>',
            'software' =>
                '<li {{attrsColumn}}>
                    <div {{attrsBlock}}>
                        {{score}}
                        <h3>{{softwareName}}</h3>
                        <div>
                            {{LinkImage}}
                        </div>
                        <p {{attrsDescription}}>{{softwareDescription}}</p>
                    </div>
                </li>',
            'user' => '<li {{attrsColumn}}>
                    <div {{attrsBlock}}>
                    <div {{CssBadge}}>
                        <div {{attrsBadge}}>
                            <span class="sr-only">{{UserType}}</span>
                        </div>
                    </div>
                        <h3 {{attrsTitle}}>{{name}}</h3>
                        <div>
                            {{LinkImage}}
                        </div>
                    </div>
                </li>',
            'header' => '<div class="align">
                            <h2>{{sectionTitle}}</h2>
                            <span class="allSee" {{attribs}}>
                                {{link}} 
                            </span>
                            {{addMore}}
                        </div>',
            'addMore' => '{{link}}'
        ]
    ];

    public $helpers = ['Html', 'Text', 'Time', 'Score'];

    public function softwares($software, $limit = false)
    {
        $result = null;
        if (!empty($software)){

            if (empty ($software->logo_directory) || empty($software->photo)) {
                $logo = $this->Html->link($this->Html->image("logos/Softwarelogo_placeholder.jpg",
                    ["alt" => $software->softwarename, "class" => "img-responsive size-logo"]),
                    ['controller' => 'Softwares', 'action' => 'view', $software->id],
                    ['escape' => false, "title" => $software->softwarename]);
            } else {
                $logo = $this->Html->link($this->Html->image(COMPTOIR_SRV_URL . $software->logo_directory . DS . $software->photo,
                    ["alt" => $software->softwarename, "class" => "img-responsive size-logo"]),
                    ['controller' => 'Softwares', 'action' => 'view', $software->id],
                    ['escape' => false, "title" => $software->softwarename]);
            }

            /**
             * Define css and bootstrap according to home page (4 col) or other pages (6 col) for softwareBlock.
             * //!\\ Bootstrap and customise Css Have to be on different html tags !
             */
            if ($limit == false) {
                $attrsColumn = $this->templater()->formatAttributes(['class' => "col-xs-12 col-sm-4 col-md-3 col-lg-2"]);
                $attrsBlock = $this->templater()->formatAttributes(['class' => 'software-unit-all backgroundUnit ']);
            } else {
                $attrsColumn = $this->templater()->formatAttributes(['class' => 'col-xs-12 col-sm-6 col-md-3 col-lg-3']);
                $attrsBlock = $this->templater()->formatAttributes(['class' => 'software-unit-home backgroundUnit']);
            }

            $result .= $this->formatTemplate('software', [
                'attrsColumn' => $attrsColumn,
                'attrsBlock' => $attrsBlock,
                'score' => $this->Score->note(isset($software->softwares_statistic->score) ? $software->softwares_statistic->score : null,
                    ['tag' => 'div', 'class' => ' score stamp ', 'title' => __d("Softwares", "Score: {0} %", isset($software->softwares_statistic->score) ? round($software->softwares_statistic->score, 0) : "NA")]),
                'softwareName' =>
                    $this->Html->link(
                        $this->Text->truncate($software->softwarename, 12, ['ellipsis' => '...', 'exact' => false]),
                        ['controller' => 'Softwares', 'action' => 'view', $software->id],
                        ['escape' => false]
                    ),
                'LinkImage' => $logo,
                'attrsDescription' => $this->templater()->formatAttributes(['class' => 'text-overflow project-description']),
                'softwareDescription' => $this->Text->truncate($software->description, 100, ['ellipsis' => '...', 'exact' => false]),
                ['class' => 'text-overflow project-description'],
            ]);
    }
        return null !== $result ? $result: null;
    }

    /**
     * @param $users
     * @param bool $limit : true -> 4 columns else 6 columns
     * @return null
     */
    public function users($user, $limit = false)
    {
        $result = null;
        if (!empty($user)) {
            if ((empty ($user->logo_directory) || empty($user->photo))) {
                $logo = $this->Html->link($this->Html->image("logos/User_placeholder.jpg",
                    ["alt" => $user->username, "class" => "img-responsive size-logo"]),
                    ['controller' => 'Users', 'action' => 'view', $user->id],
                    ['escape' => false]);
            } else {
                $logo = $this->Html->link($this->Html->image(COMPTOIR_SRV_URL . $user->logo_directory . DS . $user->photo,
                    ["alt" => $user->username, "class" => "img-responsive size-logo"]),
                    ['controller' => 'Users', 'action' => 'view', $user->id],
                    ['escape' => false]);
            }

            /**
             * Definite css and bootstrap according to home page (4 col) or other pages (6 col) for UsersBlock.
             * //!\\ Bootstrap and customise Css Have to be on different html tags !
             */
            if ($limit == false) {
                $attrsColumn = $this->templater()->formatAttributes(['class' => "col-xs-12 col-sm-4 col-md-3 col-lg-2"]);
                $attrsBlock = $this->templater()->formatAttributes(['class' => 'user-unit-all backgroundUnit list-unstyled']);
            } else {
                $attrsColumn = $this->templater()->formatAttributes(['class' => 'col-xs-12 col-sm-6 col-md-3 col-lg-3']);
                $attrsBlock = $this->templater()->formatAttributes(['class' => 'user-unit-home backgroundUnit list-unstyled']);
            }

            /**
             * Determine badge (community, asso or company, ) between UsersBlock's categories.
             */
            if ($user->user_type->name == "Administration") {
                $attrsBadge = $this->templater()->formatAttributes(['class' => "fa fa-university fa-2x", 'title' => $user->user_type->name]);
                $CssBadge = $this->templater()->formatAttributes(['class' => " stamp badge badgeAdministration"]);
            } else if ($user->user_type->name == "Company") {
                $attrsBadge = $this->templater()->formatAttributes(['class' => "fa fa-briefcase fa-2x", 'title' => $user->user_type->name]);
                $CssBadge = $this->templater()->formatAttributes(['class' => "stamp badge badgeCompany"]);
            } else {
                $attrsBadge = $this->templater()->formatAttributes(['class' => "fa fa-users fa-2x", 'title' => $user->user_type->name]);
                $CssBadge = $this->templater()->formatAttributes(['class' => " stamp badge badgeAsso"]);
            }

            $result .= $this->formatTemplate('user', [
                'UserType' => $user->user_type->name,
                'CssBadge' => $CssBadge,
                'attrsBadge' => $attrsBadge,
                'attrsColumn' => $attrsColumn,
                'attrsBlock' => $attrsBlock,
                'name' =>
                    $this->Html->link($this->Text->truncate($user->username, 35, ['ellipsis' => '...', 'exact' => false]),
                        ['controller' => 'Users', 'action' => 'view', $user->id],
                        ['escape' => false, "title" => $user->username]
                    ),
                'attrsTitle' => $this->templater()->formatAttributes(['class' => 'size-title']),
                'LinkImage' => $logo,
            ]);
        }
        return null !== $result ? $result : null;
    }

    /**
     * @param $screenshots
     * @return null
     */
    public function screenshots($screenshot)
    {
        $result = null;
        if (!empty($screenshot)) {
            if (!empty ($screenshot->url_directory) || !empty($screenshot->photo)) {
                $result .= $this->Html->tag(
                    'li',
                    $this->Html->tag(
                        'div',
                        $this->Html->link($this->Html->image(COMPTOIR_SRV_URL . $screenshot->url_directory . DS . $screenshot->photo,
                            ['alt' => __d("Screenshot of software {0}", ""), 'class' => 'img-responsive ']),
                            COMPTOIR_SRV_URL . $screenshot->url_directory . DS . $screenshot->photo,
                            ['escape' => false])
                        ,
                        ['class' => 'size-title screenShot']
                    )
                    ,
                    ["class" => " col-xs-12 col-sm-6 col-md-3 col-lg-3 "]
                );
            }
        }
        return null !== $result ? $result : null;

    }


    public function reviews( $review, $limit = true)
    {
        $result = "";
        if (!empty($review)) {
            $starsElement = "";
            for ($stars = 0; $stars < $review->evaluation; $stars++) {
                $starsElement .= $this->formatTemplate('stars',
                    [
                        'attrGlyph' => $this->templater()->formatAttributes(["class" => "glyphicon glyphicon-star"]),
                        'attrStar' => $this->templater()->formatAttributes(["class" => "sr-only"]),
                        'content' => "*",
                    ]
                );
            }

            $result .= $this->formatTemplate('review', [
                'reviewLi' => $this->templater()->formatAttributes(['class' => "col-xs-11 col-sm-12 col-md-6 col-lg-6"]),
                'attrsReview' => $this->templater()->formatAttributes(['class' => "blockReview"]),
                'AttrsBootstrap1' => $this->templater()->formatAttributes(['class' => "col-xs-3"]),
                'AttrsUserName' => $this->templater()->formatAttributes(['class' => "UserReview"]),
                'title' => $this->Text->truncate($review->title, 50, ['ellipsis' => '...', 'exact' => false]),
                'AttrsBootstrap2' => $this->templater()->formatAttributes(['class' => "col-xs-9"]),
                'userName' => $this->Html->link($review->user->username,
                    ['controller' => 'Users', 'action' => 'view', $review->user->id],
                    ['escape' => false, "title" => $review->user->username]),
                'created' => $this->Time->format(strtotime($review->created),
                    [\IntlDateFormatter::SHORT, -1],
                    I18n::locale()
                ),
                'starDiv' => $this->templater()->formatAttributes(['class' => 'ratingStar']),
                'stars' => $starsElement . " " . $review->evaluation,
                'reviewComment' => ($limit == true) ? $this->Text->truncate($review->comment, 350, ['ellipsis' => '...', 'exact' => false]) : $review->comment,
            ]);
        }
        return null !== $result ? $result : null;
    }

    /**
     * Create an ordered list of items
     * @param array $items
     * @param $name
     * @param bool $limit
     * @return null
     */
    public function items (array $items, $name ,$limit = true) {

        $result = null;
        if (!empty($items)) {
            foreach ($items as $item) {
                $result .= $this->$name($item,$limit);
            }
        }

        return null !== $result ? $this->Html->tag('ol', $result, ['class' => 'row list-unstyled']) : null;
    }

    public function block (array $items, array $options, $limit = true) {

        $seeAll = "";
        $itemsDisplay = "";

        if (!empty($items)) {
            $itemsDisplay = ($limit == true) ? $this->items(array_slice($items, 0, Configure::read("MAX_DISPLAY")),$options['type']) : $this->items($items, $options['type'] ,$limit);

            if (count($items) > Configure::read("MAX_DISPLAY") && $this->request->action == 'view') {
                $seeAll = $this->Html->link($options["tooManyMsg"],
                    ['controller' => $this->request->controller, 'action' => $options["link"]["action"], $options["link"]["id"]],
                    ['title' => $options["titleSeeAll"]],
                    ['escape' => false]);
            }
        }

        $participateLink = $this->participate($options,$options['type']);

        $header = $this->formatTemplate(
            'header',
            [
                'sectionTitle' => $options["title"],
                'spanAttr' => $this->templater()->formatAttributes($options),
                'link' => $seeAll,
                'addMore' =>  (isset($options["linkParticipate"]["authorized"])||(isset($this->request->cookies['User'])) && ($this->request->params['controller'] != 'Home' )) ? $this->formatTemplate('addMore', ['link' => $participateLink]) : null
            ]
        );

        if (strpos($itemsDisplay, '<li') == false) {
            $itemsDisplay .= $this->Html->tag(
                'p',
                $options["emptyMsg"]
            );
        }
        return $header . $itemsDisplay ;
    }

    /**
     * @param array $options
     * @return mixed
     */
    public function participate (array $options){
        /**
         * Link to participate : add something
         */
//            TODO : Refaire proprement gère les action non implémentées
        if (  $this->request->session()->read('Auth.User.user_type') !== "Company"
            && $this->request->controller != "Home")
        {
            return $this->participateAllActions ($options);

//            TODO : Refaire proprement gère les action non implémentées

        }elseif($this->request->action != "index"
            && $this->request->session()->read('Auth.User.user_type') === "Company"
            && $options['linkParticipate']['action']!=="addReview"
            && $options['linkParticipate']['action']!=="addUserOf"
            ){
//            TODO : Refaire proprement gère les action non implémentées
            return
                isset($options['linkParticipate']) ?

                $this->Html->link($options["linkParticipate"]["text"],
                    ['controller' => $this->request->controller, 'action' => $options['linkParticipate']["action"],$options['linkParticipate']["id"]],
                    ['class' => 'btn btn-default addmore', 'title' => $options["titleAddMore"]],
                    ['escape' => false]) :

                $this->Html->link(__d("Softwares",$options["titleAddMore"]),
                '#'.$options["link"]["action"],
                ['id'=>$options["link"]["action"],'class' => 'btn btn-default addmore','title' => __d("Softwares",$options["titleAddMore"])],
                ['escape' => false]);
        }
        return null;
    }

    /**
     * Display the participate link for a user as know as an administration
     * @param array $options
     * @return mixed
     */
    private  function participateAllActions (array $options){
                return
                    isset($options['linkParticipate']) ?

                        $this->Html->link($options["linkParticipate"]["text"],
                            ['controller' => $this->request->controller, 'action' => $options['linkParticipate']["action"], $options['linkParticipate']["id"]],
                            ['class' => 'btn btn-default addmore', 'title' => $options["titleAddMore"]],
                            ['escape' => false]) :

                        $this->Html->link(__d("Softwares",$options["titleAddMore"]),
                            '#'.$options["link"]["action"],
                            ['id'=>$options["link"]["action"],'class' => 'btn btn-default addmore','title' => __d("Softwares",$options["titleAddMore"])],
                            ['escape' => false]);
    }
}
